import React, { useState, useContext } from 'react';
import classNames from 'classnames';
import { ConfigProvider } from 'antd';
import { Header } from './header';
import { LeftList } from './leftList';
import './index.less';

const TipTool = (props) => {
  const { style } = props;
  const { leftSetting, headerSetting, events } = props.dataList;
  const { getPrefixCls } = useContext(ConfigProvider.ConfigContext);
  const prefixCls = getPrefixCls('panda-gis-tip');
  const data = [
    {
      name: 'middle',
      width: style.minWidth ?? '200px',
      height: style.minHeight ?? '40px',
      active: true,
    },
    {
      name: 'large',
      width: style.maxWidth ?? '200px',
      height: style.maxHeight ?? '40px',
      active: false,
    },
  ];

  const scale = {
    name: 'small',
    width: '200px',
    height: '40px',
    active: true,
  };
  const [styleState, setStyleState] = useState(data);
  const [styleScale, setScaleState] = useState(scale);
  const changeStyle = ({ name, flag }) => {
    let data = styleState.slice();
    data.map((item) => {
      if (name == item.name) {
        item.active = true;
      } else {
        item.active = false;
      }
    });
    setStyleState(data);
  };

  const changeScale = (flag) => {
    let obj = { ...styleScale };
    obj.active = flag;
    setScaleState(obj);
  };

  const computedStyle = () => {
    if (!styleScale.active) {
      return { width: styleScale.width, height: styleScale.height };
    } else {
      return styleState
        .filter((item) => item.active)
        .map(({ width, height }) => {
          return { width, height };
        })[0];
    }
  };
  const displayComput = () => {
    if (styleScale.active) {
      return { display: 'inline-block' };
    } else {
      return { display: 'none' };
    }
  };
  return (
    <div className={classNames(`${prefixCls}-Tipwripconter`)} style={computedStyle()}>
      <Header
        headerSetting={headerSetting}
        events={events}
        changeStyle={changeStyle}
        changeScale={changeScale}
      />
      <div className={classNames(`${prefixCls}-TipAll`)} style={displayComput()}>
        <div className={classNames(`${prefixCls}-Tipconter`)}>
          <div className={classNames(`${prefixCls}-Tipleft`)}>
            <LeftList leftSetting={leftSetting} />
          </div>
        </div>
        <div className={classNames(`${prefixCls}-tipfooter`)}></div>
      </div>
    </div>
  );
};

export default TipTool;
